%DECODIFICADOR STP:
%function [s,LARantd]=stpd(LARc,LARantd,d)
%Entradas:
%LARc:LAR codificados.
%LARantd:LAR de la trama anterior.
%d:señal sin envolvente.
%Salidas:
%s:trama de 160 muestras.
%LARantd:LAR actuales para la siguiente trama.
function [s,LARantd]=stpd(LARc,LARantd,d)
LARact=lardec(LARc);%decodificamos los LAR.
LARi=interpol(LARact,LARantd);%interpolamos los LAR.
rp=reflect(LARi);%calculamos los coeficientes de reflexión.
s=synfilt(d,rp);%aplicamos el filtro que restaura la envolvente.
LARantd=LARact;%actualizamos los LAR anteriores.
